@@ -7,9 +7,9 @@
 # https://github.com/manatlan/htag
 # #############################################################################
 
-from .tag import Tag,HTagException
+from .tag import H,Tag,HTagException
 
-__version__ = "0.0.8" # updated from pypoetry.toml
+__version__ = "0.2.0" # updated from pypoetry.toml
 
 __all__= ["Tag","HTagException"]
 
@@ -24,4 +24,4 @@ def _majVersion():
     v=tomlkit.parse(open('pyproject.toml').read())['tool']['poetry']['version']
     with open(file,'w+') as fid:
         fid.write( re.sub(r'__version__ = "[^"]+"','__version__ = "%s"'%v,content,1) )
-    print("htag.__version__ UPDATED to '%s'"%v)
\ No newline at end of file
+    print("htag.__version__ UPDATED to '%s'"%v)
